﻿using Gifitti.Models;
using ImageMagick;
using System.Drawing;

namespace Gifitti.Transformation
{
    /// <summary>
    /// Methods for GIF transformations kept together
    /// </summary>
    static class TransformGif
    {
        /// <summary>
        /// Resizes a GIF to be newWidth x newHeight px
        /// </summary>
        /// <param name="newWidth">New Width dimension in px.</param>
        /// <param name="newHeight">New Height dimension in px.</param>
        /// <param name="gm" cref="GifModel">GifModel being modified.</param>
        public static void resizeGif(GifModel gm, int newWidth, int newHeight)
        {
            using (MagickImageCollection collection = new MagickImageCollection())
            {
                for (int i = 0; i < gm.numberOfFrames; i++)
                {
                    collection.Add(new MagickImage(gm.GetFrame(i, true) as Bitmap));
                    collection[i].Resize(newWidth, newHeight);
                    gm.SetFrameFromImage(collection[i].ToBitmap() as Bitmap, i);
                }
            }
        }

        /// <summary>
        /// Hiden function, for future development of delay requests by users.
        /// </summary>
        /// <param name="gm">System loaded GifModel</param>
        /// <param name="delay">ms Delay between frames</param>
        internal static void saveThePlayback(GifModel gm, int delay)
        {
            using (MagickImageCollection collection = new MagickImageCollection())
            {
                for (int i = 0; i < gm.numberOfFrames; i++)
                {
                    collection.Add(new MagickImage(gm.GetFrame(i) as Bitmap));
                    collection[i].AnimationDelay = (delay/10);
                }
                
                //return collection;
                collection.Write("Test.Animated.gif");
            }
        }
    }
}
