﻿using Gifitti.Models;
using Gifitti.Transformation;
using System;
using System.IO;
using System.Windows.Forms;

namespace Gifitti.View_Models
{
    /// <summary>
    /// VM for View SaveAsXbyYPrompt
    /// </summary>
    public partial class SaveAsXbyYPrompt : Form
    {
        private GifModel gm;
        private int orignalWidth = 0;
        private int originalHeight = 0;
        private int width = 0;
        private int height = 0;

        /// <summary>
        /// Creates a new formto andle saving gifs to a new size.
        /// Aspect ratio is held using the smallest of the dimensions then scaling via aspect.
        /// </summary>
        /// <param name="width">Desired width in pixels</param>
        /// <param name="height">Desired height in pixels</param>
        /// <param name="gm">Gifmodel holding GIF desired to be modified</param>
        public SaveAsXbyYPrompt(int width, int height, GifModel gm)
        {
            InitializeComponent();
            orignalWidth = width;
            originalHeight = height;
            this.width = orignalWidth;
            this.height = originalHeight;
            WidthTextBox.Text = this.width.ToString();
            HeightTextBox.Text = this.height.ToString();
            this.gm = gm;  
        }

        /// <summary>
        /// Handler for when the user selects to save the GIF to input specifications
        /// </summary>
        /// <param name="sender">Caller object.</param>
        /// <param name="e">Event args associated with the function call, handled by .Net</param>
        private void SaveAsButtonClick(object sender, EventArgs e)
        {
            TransformGif.resizeGif(gm, width, height);
            String path = null;
            saveGifFileDialog.Filter = "GIF Files|*.gif";
            if (saveGifFileDialog.ShowDialog() == DialogResult.OK)
                path = saveGifFileDialog.FileName;

            //Handel Close
            if (path == null)
                return;

            try
            {
                TransformGif.resizeGif(gm, width, height);
                gm.saveGif(path);
            }
            catch (DirectoryNotFoundException)
            {
                TransformGif.resizeGif(gm, orignalWidth, originalHeight);
                MessageBox.Show("Save Path Invalid!");
            }
            
            this.Close();
        }

        /// <summary>
        /// Validation and verification on the width text box in the form
        /// </summary>
        /// <param name="sender">Caller object.</param>
        /// <param name="e">Event args associated with the function call, handled by .Net</param>
        private void widthChanged(object sender, EventArgs e)
        {
            int w = 0;
            if (int.TryParse(WidthTextBox.Text, out w) & w >= 0){
                width = w;
            }
        }

        /// <summary>
        /// Validation and verification on the height text box in the form
        /// </summary>
        /// <param name="sender">Caller object.</param>
        /// <param name="e">Event args associated with the function call, handled by .Net</param>
        private void heightChanged(object sender, EventArgs e)
        {
            int h = 0;
            if (int.TryParse(HeightTextBox.Text,out h) & h >= 0)
                height = h;
        }
    }
}
